@@ -11,16 +11,15 @@
 
 const int Pill::POINTS = 10;
 
-Pill::Pill(qreal p_x, qreal p_y, Maze *p_maze, const QString &p_imageId) : Element(p_x, p_y, p_maze)
+Pill::Pill(qreal p_x, qreal p_y, Maze *p_maze, const QString &p_imageId)
+    : Element(p_x, p_y, p_maze)
 {
     Element::setImageId(p_imageId);
     m_points = Pill::POINTS;
     m_type = Element::PILL;
 }
 
-Pill::~Pill()
-{
-}
+Pill::~Pill() = default;
 
 void Pill::doActionOnCollision(Kapman *p_kapman)
 {
@@ -29,3 +28,4 @@ void Pill::doActionOnCollision(Kapman *p_kapman)
     m_maze->decrementNbElem();
 }
 
+#include "moc_pill.cpp"
